{% load svg %}<a class="svg-trigger" style="text-decoration: none"
                 href="{% url 'app:svg' self.group.collection.key self.group.key self.key %}">
    {% svg_inline self theme variant=variant width='100%' height='100%' %}
</a>
