{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 1920 581.63{% endblock %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <polygon class="svg-fill-primary" opacity="0.9" points="0 581.63 1920 581.63 1920 104.55 0 581.63"></polygon>
    <polygon class="svg-fill-primary" opacity="0.5" points="0 581.63 1920 0 1920 104.55 0 581.63"></polygon>
{% endblock %}
