{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 1920 555.06{% endblock %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <path class="svg-fill-primary"
          d="M1920,555.06,1863.61,94.33A56.15,56.15,0,0,0,1801,45.42h0L0,268.64V555.06Z"></path>
    <circle class="svg-fill-primary" cx="1571.19" cy="30.59" r="7.64"></circle>
    <circle class="svg-fill-primary" cx="1540.88" cy="16.86" r="16.86"></circle>
    <circle class="svg-fill-primary" cx="978.65" cy="72.39" r="18.84"></circle>
    <circle class="svg-fill-primary" cx="488.4" cy="182.1" r="11.8"></circle>
{% endblock %}
